# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.baremetalsolution.v2",
    manifest={
        "SSHKey",
        "ListSSHKeysRequest",
        "ListSSHKeysResponse",
        "CreateSSHKeyRequest",
        "DeleteSSHKeyRequest",
    },
)


class SSHKey(proto.Message):
    r"""An SSH key, used for authorizing with the interactive serial
    console feature.

    Attributes:
        name (str):
            Output only. The name of this SSH key.
            Currently, the only valid value for the location
            is "global".
        public_key (str):
            The public SSH key. This must be in OpenSSH .authorized_keys
            format.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    public_key: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListSSHKeysRequest(proto.Message):
    r"""Message for listing the public SSH keys in a project.

    Attributes:
        parent (str):
            Required. The parent containing the SSH keys.
            Currently, the only valid value for the location
            is "global".
        page_size (int):
            The maximum number of items to return.
        page_token (str):
            The next_page_token value returned from a previous List
            request, if any.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListSSHKeysResponse(proto.Message):
    r"""Message for response of ListSSHKeys.

    Attributes:
        ssh_keys (MutableSequence[google.cloud.bare_metal_solution_v2.types.SSHKey]):
            The SSH keys registered in the project.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    ssh_keys: MutableSequence["SSHKey"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="SSHKey",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=90,
    )


class CreateSSHKeyRequest(proto.Message):
    r"""Message for registering a public SSH key in a project.

    Attributes:
        parent (str):
            Required. The parent containing the SSH keys.
        ssh_key (google.cloud.bare_metal_solution_v2.types.SSHKey):
            Required. The SSH key to register.
        ssh_key_id (str):
            Required. The ID to use for the key, which will become the
            final component of the key's resource name.

            This value must match the regex: [a-zA-Z0-9@.-_]{1,64}
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    ssh_key: "SSHKey" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="SSHKey",
    )
    ssh_key_id: str = proto.Field(
        proto.STRING,
        number=3,
    )


class DeleteSSHKeyRequest(proto.Message):
    r"""Message for deleting an SSH key from a project.

    Attributes:
        name (str):
            Required. The name of the SSH key to delete.
            Currently, the only valid value for the location
            is "global".
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Iterator,
    Optional,
    Sequence,
    Tuple,
)

from google.cloud.bare_metal_solution_v2.types import (
    instance,
    lun,
    network,
    nfs_share,
    osimage,
    provisioning,
    ssh_key,
    volume,
    volume_snapshot,
)


class ListInstancesPager:
    """A pager for iterating through ``list_instances`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListInstancesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``instances`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListInstances`` requests and continue to iterate
    through the ``instances`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListInstancesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., instance.ListInstancesResponse],
        request: instance.ListInstancesRequest,
        response: instance.ListInstancesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListInstancesRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListInstancesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = instance.ListInstancesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[instance.ListInstancesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[instance.Instance]:
        for page in self.pages:
            yield from page.instances

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListInstancesAsyncPager:
    """A pager for iterating through ``list_instances`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListInstancesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``instances`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListInstances`` requests and continue to iterate
    through the ``instances`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListInstancesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[instance.ListInstancesResponse]],
        request: instance.ListInstancesRequest,
        response: instance.ListInstancesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListInstancesRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListInstancesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = instance.ListInstancesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[instance.ListInstancesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[instance.Instance]:
        async def async_generator():
            async for page in self.pages:
                for response in page.instances:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListSSHKeysPager:
    """A pager for iterating through ``list_ssh_keys`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListSSHKeysResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``ssh_keys`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListSSHKeys`` requests and continue to iterate
    through the ``ssh_keys`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListSSHKeysResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., ssh_key.ListSSHKeysResponse],
        request: ssh_key.ListSSHKeysRequest,
        response: ssh_key.ListSSHKeysResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListSSHKeysRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListSSHKeysResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = ssh_key.ListSSHKeysRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[ssh_key.ListSSHKeysResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[ssh_key.SSHKey]:
        for page in self.pages:
            yield from page.ssh_keys

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListSSHKeysAsyncPager:
    """A pager for iterating through ``list_ssh_keys`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListSSHKeysResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``ssh_keys`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListSSHKeys`` requests and continue to iterate
    through the ``ssh_keys`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListSSHKeysResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[ssh_key.ListSSHKeysResponse]],
        request: ssh_key.ListSSHKeysRequest,
        response: ssh_key.ListSSHKeysResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListSSHKeysRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListSSHKeysResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = ssh_key.ListSSHKeysRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[ssh_key.ListSSHKeysResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[ssh_key.SSHKey]:
        async def async_generator():
            async for page in self.pages:
                for response in page.ssh_keys:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListVolumesPager:
    """A pager for iterating through ``list_volumes`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListVolumesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``volumes`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListVolumes`` requests and continue to iterate
    through the ``volumes`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListVolumesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., volume.ListVolumesResponse],
        request: volume.ListVolumesRequest,
        response: volume.ListVolumesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListVolumesRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListVolumesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = volume.ListVolumesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[volume.ListVolumesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[volume.Volume]:
        for page in self.pages:
            yield from page.volumes

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListVolumesAsyncPager:
    """A pager for iterating through ``list_volumes`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListVolumesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``volumes`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListVolumes`` requests and continue to iterate
    through the ``volumes`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListVolumesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[volume.ListVolumesResponse]],
        request: volume.ListVolumesRequest,
        response: volume.ListVolumesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListVolumesRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListVolumesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = volume.ListVolumesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[volume.ListVolumesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[volume.Volume]:
        async def async_generator():
            async for page in self.pages:
                for response in page.volumes:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListNetworksPager:
    """A pager for iterating through ``list_networks`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListNetworksResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``networks`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListNetworks`` requests and continue to iterate
    through the ``networks`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListNetworksResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., network.ListNetworksResponse],
        request: network.ListNetworksRequest,
        response: network.ListNetworksResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListNetworksRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListNetworksResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = network.ListNetworksRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[network.ListNetworksResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[network.Network]:
        for page in self.pages:
            yield from page.networks

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListNetworksAsyncPager:
    """A pager for iterating through ``list_networks`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListNetworksResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``networks`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListNetworks`` requests and continue to iterate
    through the ``networks`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListNetworksResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[network.ListNetworksResponse]],
        request: network.ListNetworksRequest,
        response: network.ListNetworksResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListNetworksRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListNetworksResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = network.ListNetworksRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[network.ListNetworksResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[network.Network]:
        async def async_generator():
            async for page in self.pages:
                for response in page.networks:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListVolumeSnapshotsPager:
    """A pager for iterating through ``list_volume_snapshots`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListVolumeSnapshotsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``volume_snapshots`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListVolumeSnapshots`` requests and continue to iterate
    through the ``volume_snapshots`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListVolumeSnapshotsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., volume_snapshot.ListVolumeSnapshotsResponse],
        request: volume_snapshot.ListVolumeSnapshotsRequest,
        response: volume_snapshot.ListVolumeSnapshotsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListVolumeSnapshotsRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListVolumeSnapshotsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = volume_snapshot.ListVolumeSnapshotsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[volume_snapshot.ListVolumeSnapshotsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[volume_snapshot.VolumeSnapshot]:
        for page in self.pages:
            yield from page.volume_snapshots

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListVolumeSnapshotsAsyncPager:
    """A pager for iterating through ``list_volume_snapshots`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListVolumeSnapshotsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``volume_snapshots`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListVolumeSnapshots`` requests and continue to iterate
    through the ``volume_snapshots`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListVolumeSnapshotsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[volume_snapshot.ListVolumeSnapshotsResponse]],
        request: volume_snapshot.ListVolumeSnapshotsRequest,
        response: volume_snapshot.ListVolumeSnapshotsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListVolumeSnapshotsRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListVolumeSnapshotsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = volume_snapshot.ListVolumeSnapshotsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[volume_snapshot.ListVolumeSnapshotsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[volume_snapshot.VolumeSnapshot]:
        async def async_generator():
            async for page in self.pages:
                for response in page.volume_snapshots:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListLunsPager:
    """A pager for iterating through ``list_luns`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListLunsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``luns`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListLuns`` requests and continue to iterate
    through the ``luns`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListLunsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., lun.ListLunsResponse],
        request: lun.ListLunsRequest,
        response: lun.ListLunsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListLunsRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListLunsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = lun.ListLunsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[lun.ListLunsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[lun.Lun]:
        for page in self.pages:
            yield from page.luns

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListLunsAsyncPager:
    """A pager for iterating through ``list_luns`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListLunsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``luns`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListLuns`` requests and continue to iterate
    through the ``luns`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListLunsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[lun.ListLunsResponse]],
        request: lun.ListLunsRequest,
        response: lun.ListLunsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListLunsRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListLunsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = lun.ListLunsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[lun.ListLunsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[lun.Lun]:
        async def async_generator():
            async for page in self.pages:
                for response in page.luns:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListNfsSharesPager:
    """A pager for iterating through ``list_nfs_shares`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListNfsSharesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``nfs_shares`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListNfsShares`` requests and continue to iterate
    through the ``nfs_shares`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListNfsSharesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., nfs_share.ListNfsSharesResponse],
        request: nfs_share.ListNfsSharesRequest,
        response: nfs_share.ListNfsSharesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListNfsSharesRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListNfsSharesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = nfs_share.ListNfsSharesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[nfs_share.ListNfsSharesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[nfs_share.NfsShare]:
        for page in self.pages:
            yield from page.nfs_shares

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListNfsSharesAsyncPager:
    """A pager for iterating through ``list_nfs_shares`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListNfsSharesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``nfs_shares`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListNfsShares`` requests and continue to iterate
    through the ``nfs_shares`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListNfsSharesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[nfs_share.ListNfsSharesResponse]],
        request: nfs_share.ListNfsSharesRequest,
        response: nfs_share.ListNfsSharesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListNfsSharesRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListNfsSharesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = nfs_share.ListNfsSharesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[nfs_share.ListNfsSharesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[nfs_share.NfsShare]:
        async def async_generator():
            async for page in self.pages:
                for response in page.nfs_shares:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListProvisioningQuotasPager:
    """A pager for iterating through ``list_provisioning_quotas`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListProvisioningQuotasResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``provisioning_quotas`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListProvisioningQuotas`` requests and continue to iterate
    through the ``provisioning_quotas`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListProvisioningQuotasResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., provisioning.ListProvisioningQuotasResponse],
        request: provisioning.ListProvisioningQuotasRequest,
        response: provisioning.ListProvisioningQuotasResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListProvisioningQuotasRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListProvisioningQuotasResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = provisioning.ListProvisioningQuotasRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[provisioning.ListProvisioningQuotasResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[provisioning.ProvisioningQuota]:
        for page in self.pages:
            yield from page.provisioning_quotas

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListProvisioningQuotasAsyncPager:
    """A pager for iterating through ``list_provisioning_quotas`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListProvisioningQuotasResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``provisioning_quotas`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListProvisioningQuotas`` requests and continue to iterate
    through the ``provisioning_quotas`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListProvisioningQuotasResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[provisioning.ListProvisioningQuotasResponse]],
        request: provisioning.ListProvisioningQuotasRequest,
        response: provisioning.ListProvisioningQuotasResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListProvisioningQuotasRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListProvisioningQuotasResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = provisioning.ListProvisioningQuotasRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[provisioning.ListProvisioningQuotasResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[provisioning.ProvisioningQuota]:
        async def async_generator():
            async for page in self.pages:
                for response in page.provisioning_quotas:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListOSImagesPager:
    """A pager for iterating through ``list_os_images`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListOSImagesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``os_images`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListOSImages`` requests and continue to iterate
    through the ``os_images`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListOSImagesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., osimage.ListOSImagesResponse],
        request: osimage.ListOSImagesRequest,
        response: osimage.ListOSImagesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListOSImagesRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListOSImagesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = osimage.ListOSImagesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[osimage.ListOSImagesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[osimage.OSImage]:
        for page in self.pages:
            yield from page.os_images

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListOSImagesAsyncPager:
    """A pager for iterating through ``list_os_images`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.bare_metal_solution_v2.types.ListOSImagesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``os_images`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListOSImages`` requests and continue to iterate
    through the ``os_images`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.bare_metal_solution_v2.types.ListOSImagesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[osimage.ListOSImagesResponse]],
        request: osimage.ListOSImagesRequest,
        response: osimage.ListOSImagesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.bare_metal_solution_v2.types.ListOSImagesRequest):
                The initial request object.
            response (google.cloud.bare_metal_solution_v2.types.ListOSImagesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = osimage.ListOSImagesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[osimage.ListOSImagesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[osimage.OSImage]:
        async def async_generator():
            async for page in self.pages:
                for response in page.os_images:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1, operations_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.cloud.location import locations_pb2  # type: ignore
from google.iam.v1 import iam_policy_pb2  # type: ignore
from google.iam.v1 import policy_pb2  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.oauth2 import service_account  # type: ignore
from google.protobuf import empty_pb2  # type: ignore

from google.cloud.bare_metal_solution_v2 import gapic_version as package_version
from google.cloud.bare_metal_solution_v2.types import nfs_share as gcb_nfs_share
from google.cloud.bare_metal_solution_v2.types import (
    volume_snapshot as gcb_volume_snapshot,
)
from google.cloud.bare_metal_solution_v2.types import instance
from google.cloud.bare_metal_solution_v2.types import instance as gcb_instance
from google.cloud.bare_metal_solution_v2.types import lun
from google.cloud.bare_metal_solution_v2.types import network
from google.cloud.bare_metal_solution_v2.types import network as gcb_network
from google.cloud.bare_metal_solution_v2.types import nfs_share
from google.cloud.bare_metal_solution_v2.types import osimage, provisioning
from google.cloud.bare_metal_solution_v2.types import ssh_key
from google.cloud.bare_metal_solution_v2.types import ssh_key as gcb_ssh_key
from google.cloud.bare_metal_solution_v2.types import volume
from google.cloud.bare_metal_solution_v2.types import volume as gcb_volume
from google.cloud.bare_metal_solution_v2.types import volume_snapshot

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


class BareMetalSolutionTransport(abc.ABC):
    """Abstract transport class for BareMetalSolution."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "baremetalsolution.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_instances: gapic_v1.method.wrap_method(
                self.list_instances,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_instance: gapic_v1.method.wrap_method(
                self.get_instance,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_instance: gapic_v1.method.wrap_method(
                self.update_instance,
                default_timeout=None,
                client_info=client_info,
            ),
            self.rename_instance: gapic_v1.method.wrap_method(
                self.rename_instance,
                default_timeout=None,
                client_info=client_info,
            ),
            self.reset_instance: gapic_v1.method.wrap_method(
                self.reset_instance,
                default_timeout=None,
                client_info=client_info,
            ),
            self.start_instance: gapic_v1.method.wrap_method(
                self.start_instance,
                default_timeout=None,
                client_info=client_info,
            ),
            self.stop_instance: gapic_v1.method.wrap_method(
                self.stop_instance,
                default_timeout=None,
                client_info=client_info,
            ),
            self.enable_interactive_serial_console: gapic_v1.method.wrap_method(
                self.enable_interactive_serial_console,
                default_timeout=None,
                client_info=client_info,
            ),
            self.disable_interactive_serial_console: gapic_v1.method.wrap_method(
                self.disable_interactive_serial_console,
                default_timeout=None,
                client_info=client_info,
            ),
            self.detach_lun: gapic_v1.method.wrap_method(
                self.detach_lun,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_ssh_keys: gapic_v1.method.wrap_method(
                self.list_ssh_keys,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_ssh_key: gapic_v1.method.wrap_method(
                self.create_ssh_key,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_ssh_key: gapic_v1.method.wrap_method(
                self.delete_ssh_key,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_volumes: gapic_v1.method.wrap_method(
                self.list_volumes,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_volume: gapic_v1.method.wrap_method(
                self.get_volume,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_volume: gapic_v1.method.wrap_method(
                self.update_volume,
                default_timeout=None,
                client_info=client_info,
            ),
            self.rename_volume: gapic_v1.method.wrap_method(
                self.rename_volume,
                default_timeout=None,
                client_info=client_info,
            ),
            self.evict_volume: gapic_v1.method.wrap_method(
                self.evict_volume,
                default_timeout=None,
                client_info=client_info,
            ),
            self.resize_volume: gapic_v1.method.wrap_method(
                self.resize_volume,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_networks: gapic_v1.method.wrap_method(
                self.list_networks,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_network_usage: gapic_v1.method.wrap_method(
                self.list_network_usage,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_network: gapic_v1.method.wrap_method(
                self.get_network,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_network: gapic_v1.method.wrap_method(
                self.update_network,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_volume_snapshot: gapic_v1.method.wrap_method(
                self.create_volume_snapshot,
                default_timeout=None,
                client_info=client_info,
            ),
            self.restore_volume_snapshot: gapic_v1.method.wrap_method(
                self.restore_volume_snapshot,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_volume_snapshot: gapic_v1.method.wrap_method(
                self.delete_volume_snapshot,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_volume_snapshot: gapic_v1.method.wrap_method(
                self.get_volume_snapshot,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_volume_snapshots: gapic_v1.method.wrap_method(
                self.list_volume_snapshots,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_lun: gapic_v1.method.wrap_method(
                self.get_lun,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_luns: gapic_v1.method.wrap_method(
                self.list_luns,
                default_timeout=None,
                client_info=client_info,
            ),
            self.evict_lun: gapic_v1.method.wrap_method(
                self.evict_lun,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_nfs_share: gapic_v1.method.wrap_method(
                self.get_nfs_share,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_nfs_shares: gapic_v1.method.wrap_method(
                self.list_nfs_shares,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_nfs_share: gapic_v1.method.wrap_method(
                self.update_nfs_share,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_nfs_share: gapic_v1.method.wrap_method(
                self.create_nfs_share,
                default_timeout=None,
                client_info=client_info,
            ),
            self.rename_nfs_share: gapic_v1.method.wrap_method(
                self.rename_nfs_share,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_nfs_share: gapic_v1.method.wrap_method(
                self.delete_nfs_share,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_provisioning_quotas: gapic_v1.method.wrap_method(
                self.list_provisioning_quotas,
                default_timeout=None,
                client_info=client_info,
            ),
            self.submit_provisioning_config: gapic_v1.method.wrap_method(
                self.submit_provisioning_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_provisioning_config: gapic_v1.method.wrap_method(
                self.get_provisioning_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_provisioning_config: gapic_v1.method.wrap_method(
                self.create_provisioning_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_provisioning_config: gapic_v1.method.wrap_method(
                self.update_provisioning_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.rename_network: gapic_v1.method.wrap_method(
                self.rename_network,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_os_images: gapic_v1.method.wrap_method(
                self.list_os_images,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def list_instances(
        self,
    ) -> Callable[
        [instance.ListInstancesRequest],
        Union[
            instance.ListInstancesResponse, Awaitable[instance.ListInstancesResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_instance(
        self,
    ) -> Callable[
        [instance.GetInstanceRequest],
        Union[instance.Instance, Awaitable[instance.Instance]],
    ]:
        raise NotImplementedError()

    @property
    def update_instance(
        self,
    ) -> Callable[
        [gcb_instance.UpdateInstanceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def rename_instance(
        self,
    ) -> Callable[
        [instance.RenameInstanceRequest],
        Union[instance.Instance, Awaitable[instance.Instance]],
    ]:
        raise NotImplementedError()

    @property
    def reset_instance(
        self,
    ) -> Callable[
        [instance.ResetInstanceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def start_instance(
        self,
    ) -> Callable[
        [instance.StartInstanceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def stop_instance(
        self,
    ) -> Callable[
        [instance.StopInstanceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def enable_interactive_serial_console(
        self,
    ) -> Callable[
        [instance.EnableInteractiveSerialConsoleRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def disable_interactive_serial_console(
        self,
    ) -> Callable[
        [instance.DisableInteractiveSerialConsoleRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def detach_lun(
        self,
    ) -> Callable[
        [gcb_instance.DetachLunRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_ssh_keys(
        self,
    ) -> Callable[
        [ssh_key.ListSSHKeysRequest],
        Union[ssh_key.ListSSHKeysResponse, Awaitable[ssh_key.ListSSHKeysResponse]],
    ]:
        raise NotImplementedError()

    @property
    def create_ssh_key(
        self,
    ) -> Callable[
        [gcb_ssh_key.CreateSSHKeyRequest],
        Union[gcb_ssh_key.SSHKey, Awaitable[gcb_ssh_key.SSHKey]],
    ]:
        raise NotImplementedError()

    @property
    def delete_ssh_key(
        self,
    ) -> Callable[
        [ssh_key.DeleteSSHKeyRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def list_volumes(
        self,
    ) -> Callable[
        [volume.ListVolumesRequest],
        Union[volume.ListVolumesResponse, Awaitable[volume.ListVolumesResponse]],
    ]:
        raise NotImplementedError()

    @property
    def get_volume(
        self,
    ) -> Callable[
        [volume.GetVolumeRequest], Union[volume.Volume, Awaitable[volume.Volume]]
    ]:
        raise NotImplementedError()

    @property
    def update_volume(
        self,
    ) -> Callable[
        [gcb_volume.UpdateVolumeRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def rename_volume(
        self,
    ) -> Callable[
        [volume.RenameVolumeRequest], Union[volume.Volume, Awaitable[volume.Volume]]
    ]:
        raise NotImplementedError()

    @property
    def evict_volume(
        self,
    ) -> Callable[
        [volume.EvictVolumeRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def resize_volume(
        self,
    ) -> Callable[
        [gcb_volume.ResizeVolumeRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_networks(
        self,
    ) -> Callable[
        [network.ListNetworksRequest],
        Union[network.ListNetworksResponse, Awaitable[network.ListNetworksResponse]],
    ]:
        raise NotImplementedError()

    @property
    def list_network_usage(
        self,
    ) -> Callable[
        [network.ListNetworkUsageRequest],
        Union[
            network.ListNetworkUsageResponse,
            Awaitable[network.ListNetworkUsageResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_network(
        self,
    ) -> Callable[
        [network.GetNetworkRequest], Union[network.Network, Awaitable[network.Network]]
    ]:
        raise NotImplementedError()

    @property
    def update_network(
        self,
    ) -> Callable[
        [gcb_network.UpdateNetworkRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def create_volume_snapshot(
        self,
    ) -> Callable[
        [gcb_volume_snapshot.CreateVolumeSnapshotRequest],
        Union[
            gcb_volume_snapshot.VolumeSnapshot,
            Awaitable[gcb_volume_snapshot.VolumeSnapshot],
        ],
    ]:
        raise NotImplementedError()

    @property
    def restore_volume_snapshot(
        self,
    ) -> Callable[
        [gcb_volume_snapshot.RestoreVolumeSnapshotRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def delete_volume_snapshot(
        self,
    ) -> Callable[
        [volume_snapshot.DeleteVolumeSnapshotRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def get_volume_snapshot(
        self,
    ) -> Callable[
        [volume_snapshot.GetVolumeSnapshotRequest],
        Union[
            volume_snapshot.VolumeSnapshot, Awaitable[volume_snapshot.VolumeSnapshot]
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_volume_snapshots(
        self,
    ) -> Callable[
        [volume_snapshot.ListVolumeSnapshotsRequest],
        Union[
            volume_snapshot.ListVolumeSnapshotsResponse,
            Awaitable[volume_snapshot.ListVolumeSnapshotsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_lun(
        self,
    ) -> Callable[[lun.GetLunRequest], Union[lun.Lun, Awaitable[lun.Lun]]]:
        raise NotImplementedError()

    @property
    def list_luns(
        self,
    ) -> Callable[
        [lun.ListLunsRequest],
        Union[lun.ListLunsResponse, Awaitable[lun.ListLunsResponse]],
    ]:
        raise NotImplementedError()

    @property
    def evict_lun(
        self,
    ) -> Callable[
        [lun.EvictLunRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def get_nfs_share(
        self,
    ) -> Callable[
        [nfs_share.GetNfsShareRequest],
        Union[nfs_share.NfsShare, Awaitable[nfs_share.NfsShare]],
    ]:
        raise NotImplementedError()

    @property
    def list_nfs_shares(
        self,
    ) -> Callable[
        [nfs_share.ListNfsSharesRequest],
        Union[
            nfs_share.ListNfsSharesResponse, Awaitable[nfs_share.ListNfsSharesResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_nfs_share(
        self,
    ) -> Callable[
        [gcb_nfs_share.UpdateNfsShareRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def create_nfs_share(
        self,
    ) -> Callable[
        [gcb_nfs_share.CreateNfsShareRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def rename_nfs_share(
        self,
    ) -> Callable[
        [nfs_share.RenameNfsShareRequest],
        Union[nfs_share.NfsShare, Awaitable[nfs_share.NfsShare]],
    ]:
        raise NotImplementedError()

    @property
    def delete_nfs_share(
        self,
    ) -> Callable[
        [nfs_share.DeleteNfsShareRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_provisioning_quotas(
        self,
    ) -> Callable[
        [provisioning.ListProvisioningQuotasRequest],
        Union[
            provisioning.ListProvisioningQuotasResponse,
            Awaitable[provisioning.ListProvisioningQuotasResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def submit_provisioning_config(
        self,
    ) -> Callable[
        [provisioning.SubmitProvisioningConfigRequest],
        Union[
            provisioning.SubmitProvisioningConfigResponse,
            Awaitable[provisioning.SubmitProvisioningConfigResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_provisioning_config(
        self,
    ) -> Callable[
        [provisioning.GetProvisioningConfigRequest],
        Union[
            provisioning.ProvisioningConfig, Awaitable[provisioning.ProvisioningConfig]
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_provisioning_config(
        self,
    ) -> Callable[
        [provisioning.CreateProvisioningConfigRequest],
        Union[
            provisioning.ProvisioningConfig, Awaitable[provisioning.ProvisioningConfig]
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_provisioning_config(
        self,
    ) -> Callable[
        [provisioning.UpdateProvisioningConfigRequest],
        Union[
            provisioning.ProvisioningConfig, Awaitable[provisioning.ProvisioningConfig]
        ],
    ]:
        raise NotImplementedError()

    @property
    def rename_network(
        self,
    ) -> Callable[
        [network.RenameNetworkRequest],
        Union[network.Network, Awaitable[network.Network]],
    ]:
        raise NotImplementedError()

    @property
    def list_os_images(
        self,
    ) -> Callable[
        [osimage.ListOSImagesRequest],
        Union[osimage.ListOSImagesResponse, Awaitable[osimage.ListOSImagesResponse]],
    ]:
        raise NotImplementedError()

    @property
    def get_location(
        self,
    ) -> Callable[
        [locations_pb2.GetLocationRequest],
        Union[locations_pb2.Location, Awaitable[locations_pb2.Location]],
    ]:
        raise NotImplementedError()

    @property
    def list_locations(
        self,
    ) -> Callable[
        [locations_pb2.ListLocationsRequest],
        Union[
            locations_pb2.ListLocationsResponse,
            Awaitable[locations_pb2.ListLocationsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("BareMetalSolutionTransport",)



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.baremetalsolution.v2",
    manifest={
        "NfsShare",
        "GetNfsShareRequest",
        "ListNfsSharesRequest",
        "ListNfsSharesResponse",
        "UpdateNfsShareRequest",
        "RenameNfsShareRequest",
        "CreateNfsShareRequest",
        "DeleteNfsShareRequest",
    },
)


class NfsShare(proto.Message):
    r"""An NFS share.

    Attributes:
        name (str):
            Immutable. The name of the NFS share.
        nfs_share_id (str):
            Output only. An identifier for the NFS share, generated by
            the backend. This field will be deprecated in the future,
            use ``id`` instead.
        id (str):
            Output only. An identifier for the NFS share, generated by
            the backend. This is the same value as nfs_share_id and will
            replace it in the future.
        state (google.cloud.bare_metal_solution_v2.types.NfsShare.State):
            Output only. The state of the NFS share.
        volume (str):
            Output only. The underlying volume of the
            share. Created automatically during
            provisioning.
        allowed_clients (MutableSequence[google.cloud.bare_metal_solution_v2.types.NfsShare.AllowedClient]):
            List of allowed access points.
        labels (MutableMapping[str, str]):
            Labels as key value pairs.
        requested_size_gib (int):
            The requested size, in GiB.
        storage_type (google.cloud.bare_metal_solution_v2.types.NfsShare.StorageType):
            Immutable. The storage type of the underlying
            volume.
    """

    class State(proto.Enum):
        r"""The possible states for this NFS share.

        Values:
            STATE_UNSPECIFIED (0):
                The share is in an unknown state.
            PROVISIONED (1):
                The share has been provisioned.
            CREATING (2):
                The NFS Share is being created.
            UPDATING (3):
                The NFS Share is being updated.
            DELETING (4):
                The NFS Share has been requested to be
                deleted.
        """
        STATE_UNSPECIFIED = 0
        PROVISIONED = 1
        CREATING = 2
        UPDATING = 3
        DELETING = 4

    class MountPermissions(proto.Enum):
        r"""The possible mount permissions.

        Values:
            MOUNT_PERMISSIONS_UNSPECIFIED (0):
                Permissions were not specified.
            READ (1):
                NFS share can be mount with read-only
                permissions.
            READ_WRITE (2):
                NFS share can be mount with read-write
                permissions.
        """
        MOUNT_PERMISSIONS_UNSPECIFIED = 0
        READ = 1
        READ_WRITE = 2

    class StorageType(proto.Enum):
        r"""The storage type for a volume.

        Values:
            STORAGE_TYPE_UNSPECIFIED (0):
                The storage type for this volume is unknown.
            SSD (1):
                The storage type for this volume is SSD.
            HDD (2):
                This storage type for this volume is HDD.
        """
        STORAGE_TYPE_UNSPECIFIED = 0
        SSD = 1
        HDD = 2

    class AllowedClient(proto.Message):
        r"""Represents an 'access point' for the share.

        Attributes:
            network (str):
                The network the access point sits on.
            share_ip (str):
                Output only. The IP address of the share on this network.
                Assigned automatically during provisioning based on the
                network's services_cidr.
            allowed_clients_cidr (str):
                The subnet of IP addresses permitted to
                access the share.
            mount_permissions (google.cloud.bare_metal_solution_v2.types.NfsShare.MountPermissions):
                Mount permissions.
            allow_dev (bool):
                Allow dev flag.  Which controls whether to
                allow creation of devices.
            allow_suid (bool):
                Allow the setuid flag.
            no_root_squash (bool):
                Disable root squashing, which is a feature of
                NFS. Root squash is a special mapping of the
                remote superuser (root) identity when using
                identity authentication.
            nfs_path (str):
                Output only. The path to access NFS, in
                format shareIP:/InstanceID InstanceID is the
                generated ID instead of customer provided name.
                example like "10.0.0.0:/g123456789-nfs001".
        """

        network: str = proto.Field(
            proto.STRING,
            number=1,
        )
        share_ip: str = proto.Field(
            proto.STRING,
            number=2,
        )
        allowed_clients_cidr: str = proto.Field(
            proto.STRING,
            number=3,
        )
        mount_permissions: "NfsShare.MountPermissions" = proto.Field(
            proto.ENUM,
            number=4,
            enum="NfsShare.MountPermissions",
        )
        allow_dev: bool = proto.Field(
            proto.BOOL,
            number=5,
        )
        allow_suid: bool = proto.Field(
            proto.BOOL,
            number=6,
        )
        no_root_squash: bool = proto.Field(
            proto.BOOL,
            number=7,
        )
        nfs_path: str = proto.Field(
            proto.STRING,
            number=8,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    nfs_share_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    id: str = proto.Field(
        proto.STRING,
        number=8,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=3,
        enum=State,
    )
    volume: str = proto.Field(
        proto.STRING,
        number=4,
    )
    allowed_clients: MutableSequence[AllowedClient] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=AllowedClient,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=6,
    )
    requested_size_gib: int = proto.Field(
        proto.INT64,
        number=7,
    )
    storage_type: StorageType = proto.Field(
        proto.ENUM,
        number=9,
        enum=StorageType,
    )


class GetNfsShareRequest(proto.Message):
    r"""Message for requesting NFS share information.

    Attributes:
        name (str):
            Required. Name of the resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListNfsSharesRequest(proto.Message):
    r"""Message for requesting a list of NFS shares.

    Attributes:
        parent (str):
            Required. Parent value for
            ListNfsSharesRequest.
        page_size (int):
            Requested page size. The server might return
            fewer items than requested. If unspecified,
            server will pick an appropriate default.
        page_token (str):
            A token identifying a page of results from
            the server.
        filter (str):
            List filter.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListNfsSharesResponse(proto.Message):
    r"""Response message containing the list of NFS shares.

    Attributes:
        nfs_shares (MutableSequence[google.cloud.bare_metal_solution_v2.types.NfsShare]):
            The list of NFS shares.
        next_page_token (str):
            A token identifying a page of results from
            the server.
        unreachable (MutableSequence[str]):
            Locations that could not be reached.
    """

    @property
    def raw_page(self):
        return self

    nfs_shares: MutableSequence["NfsShare"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="NfsShare",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    unreachable: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class UpdateNfsShareRequest(proto.Message):
    r"""Message requesting to updating an NFS share.

    Attributes:
        nfs_share (google.cloud.bare_metal_solution_v2.types.NfsShare):
            Required. The NFS share to update.

            The ``name`` field is used to identify the NFS share to
            update. Format:
            projects/{project}/locations/{location}/nfsShares/{nfs_share}
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The list of fields to update. The only currently supported
            fields are: ``labels`` ``allowed_clients``
    """

    nfs_share: "NfsShare" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="NfsShare",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class RenameNfsShareRequest(proto.Message):
    r"""Message requesting rename of a server.

    Attributes:
        name (str):
            Required. The ``name`` field is used to identify the
            nfsshare. Format:
            projects/{project}/locations/{location}/nfsshares/{nfsshare}
        new_nfsshare_id (str):
            Required. The new ``id`` of the nfsshare.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    new_nfsshare_id: str = proto.Field(
        proto.STRING,
        number=2,
    )


class CreateNfsShareRequest(proto.Message):
    r"""Message for creating an NFS share.

    Attributes:
        parent (str):
            Required. The parent project and location.
        nfs_share (google.cloud.bare_metal_solution_v2.types.NfsShare):
            Required. The NfsShare to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    nfs_share: "NfsShare" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="NfsShare",
    )


class DeleteNfsShareRequest(proto.Message):
    r"""Message for deleting an NFS share.

    Attributes:
        name (str):
            Required. The name of the NFS share to
            delete.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.bare_metal_solution_v2.types import common, network

__protobuf__ = proto.module(
    package="google.cloud.baremetalsolution.v2",
    manifest={
        "ProvisioningConfig",
        "SubmitProvisioningConfigRequest",
        "SubmitProvisioningConfigResponse",
        "ProvisioningQuota",
        "ListProvisioningQuotasRequest",
        "ListProvisioningQuotasResponse",
        "InstanceConfig",
        "VolumeConfig",
        "NetworkConfig",
        "InstanceQuota",
        "GetProvisioningConfigRequest",
        "CreateProvisioningConfigRequest",
        "UpdateProvisioningConfigRequest",
    },
)


class ProvisioningConfig(proto.Message):
    r"""A provisioning configuration.

    Attributes:
        name (str):
            Output only. The system-generated name of the
            provisioning config. This follows the UUID
            format.
        instances (MutableSequence[google.cloud.bare_metal_solution_v2.types.InstanceConfig]):
            Instances to be created.
        networks (MutableSequence[google.cloud.bare_metal_solution_v2.types.NetworkConfig]):
            Networks to be created.
        volumes (MutableSequence[google.cloud.bare_metal_solution_v2.types.VolumeConfig]):
            Volumes to be created.
        ticket_id (str):
            A generated ticket id to track provisioning
            request.
        handover_service_account (str):
            A service account to enable customers to
            access instance credentials upon handover.
        email (str):
            Email provided to send a confirmation with
            provisioning config to. Deprecated in favour of
            email field in request messages.
        state (google.cloud.bare_metal_solution_v2.types.ProvisioningConfig.State):
            Output only. State of ProvisioningConfig.
        location (str):
            Optional. Location name of this
            ProvisioningConfig. It is optional only for
            Intake UI transition period.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Last update timestamp.
        cloud_console_uri (str):
            Output only. URI to Cloud Console UI view of
            this provisioning config.
        vpc_sc_enabled (bool):
            If true, VPC SC is enabled for the cluster.
        status_message (str):
            Optional status messages associated with the
            FAILED state.
        custom_id (str):
            Optional. The user-defined identifier of the
            provisioning config.
    """

    class State(proto.Enum):
        r"""The possible states for this ProvisioningConfig.

        Values:
            STATE_UNSPECIFIED (0):
                State wasn't specified.
            DRAFT (1):
                ProvisioningConfig is a draft and can be
                freely modified.
            SUBMITTED (2):
                ProvisioningConfig was already submitted and
                cannot be modified.
            PROVISIONING (3):
                ProvisioningConfig was in the provisioning
                state.  Initially this state comes from the work
                order table in big query when SNOW is used.
                Later this field can be set by the work order
                API.
            PROVISIONED (4):
                ProvisioningConfig was provisioned, meaning
                the resources exist.
            VALIDATED (5):
                ProvisioningConfig was validated.  A
                validation tool will be run to set this state.
            CANCELLED (6):
                ProvisioningConfig was canceled.
            FAILED (7):
                The request is submitted for provisioning,
                with error return.
        """
        STATE_UNSPECIFIED = 0
        DRAFT = 1
        SUBMITTED = 2
        PROVISIONING = 3
        PROVISIONED = 4
        VALIDATED = 5
        CANCELLED = 6
        FAILED = 7

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    instances: MutableSequence["InstanceConfig"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="InstanceConfig",
    )
    networks: MutableSequence["NetworkConfig"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="NetworkConfig",
    )
    volumes: MutableSequence["VolumeConfig"] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message="VolumeConfig",
    )
    ticket_id: str = proto.Field(
        proto.STRING,
        number=5,
    )
    handover_service_account: str = proto.Field(
        proto.STRING,
        number=6,
    )
    email: str = proto.Field(
        proto.STRING,
        number=7,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=8,
        enum=State,
    )
    location: str = proto.Field(
        proto.STRING,
        number=9,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=10,
        message=timestamp_pb2.Timestamp,
    )
    cloud_console_uri: str = proto.Field(
        proto.STRING,
        number=11,
    )
    vpc_sc_enabled: bool = proto.Field(
        proto.BOOL,
        number=12,
    )
    status_message: str = proto.Field(
        proto.STRING,
        number=13,
    )
    custom_id: str = proto.Field(
        proto.STRING,
        number=14,
    )


class SubmitProvisioningConfigRequest(proto.Message):
    r"""Request for SubmitProvisioningConfig.

    Attributes:
        parent (str):
            Required. The parent project and location
            containing the ProvisioningConfig.
        provisioning_config (google.cloud.bare_metal_solution_v2.types.ProvisioningConfig):
            Required. The ProvisioningConfig to create.
        email (str):
            Optional. Email provided to send a
            confirmation with provisioning config to.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    provisioning_config: "ProvisioningConfig" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="ProvisioningConfig",
    )
    email: str = proto.Field(
        proto.STRING,
        number=3,
    )


class SubmitProvisioningConfigResponse(proto.Message):
    r"""Response for SubmitProvisioningConfig.

    Attributes:
        provisioning_config (google.cloud.bare_metal_solution_v2.types.ProvisioningConfig):
            The submitted provisioning config.
    """

    provisioning_config: "ProvisioningConfig" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="ProvisioningConfig",
    )


class ProvisioningQuota(proto.Message):
    r"""A provisioning quota for a given project.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Output only. The name of the provisioning
            quota.
        asset_type (google.cloud.bare_metal_solution_v2.types.ProvisioningQuota.AssetType):
            The asset type of this provisioning quota.
        gcp_service (str):
            The gcp service of the provisioning quota.
        location (str):
            The specific location of the provisioining
            quota.
        available_count (int):
            The available count of the provisioning
            quota.
        instance_quota (google.cloud.bare_metal_solution_v2.types.InstanceQuota):
            Instance quota.

            This field is a member of `oneof`_ ``quota``.
        server_count (int):
            Server count.

            This field is a member of `oneof`_ ``availability``.
        network_bandwidth (int):
            Network bandwidth, Gbps

            This field is a member of `oneof`_ ``availability``.
        storage_gib (int):
            Storage size (GB).

            This field is a member of `oneof`_ ``availability``.
    """

    class AssetType(proto.Enum):
        r"""The available asset types for intake.

        Values:
            ASSET_TYPE_UNSPECIFIED (0):
                The unspecified type.
            ASSET_TYPE_SERVER (1):
                The server asset type.
            ASSET_TYPE_STORAGE (2):
                The storage asset type.
            ASSET_TYPE_NETWORK (3):
                The network asset type.
        """
        ASSET_TYPE_UNSPECIFIED = 0
        ASSET_TYPE_SERVER = 1
        ASSET_TYPE_STORAGE = 2
        ASSET_TYPE_NETWORK = 3

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    asset_type: AssetType = proto.Field(
        proto.ENUM,
        number=2,
        enum=AssetType,
    )
    gcp_service: str = proto.Field(
        proto.STRING,
        number=3,
    )
    location: str = proto.Field(
        proto.STRING,
        number=4,
    )
    available_count: int = proto.Field(
        proto.INT32,
        number=5,
    )
    instance_quota: "InstanceQuota" = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="quota",
        message="InstanceQuota",
    )
    server_count: int = proto.Field(
        proto.INT64,
        number=7,
        oneof="availability",
    )
    network_bandwidth: int = proto.Field(
        proto.INT64,
        number=8,
        oneof="availability",
    )
    storage_gib: int = proto.Field(
        proto.INT64,
        number=9,
        oneof="availability",
    )


class ListProvisioningQuotasRequest(proto.Message):
    r"""Message for requesting the list of provisioning quotas.

    Attributes:
        parent (str):
            Required. Parent value for
            ListProvisioningQuotasRequest.
        page_size (int):
            Requested page size. The server might return fewer items
            than requested. If unspecified, server will pick an
            appropriate default. Notice that page_size field is not
            supported and won't be respected in the API request for now,
            will be updated when pagination is supported.
        page_token (str):
            A token identifying a page of results from
            the server.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListProvisioningQuotasResponse(proto.Message):
    r"""Response message for the list of provisioning quotas.

    Attributes:
        provisioning_quotas (MutableSequence[google.cloud.bare_metal_solution_v2.types.ProvisioningQuota]):
            The provisioning quotas registered in this
            project.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    provisioning_quotas: MutableSequence["ProvisioningQuota"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="ProvisioningQuota",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class InstanceConfig(proto.Message):
    r"""Configuration parameters for a new instance.

    Attributes:
        name (str):
            Output only. The name of the instance config.
        id (str):
            A transient unique identifier to idenfity an
            instance within an ProvisioningConfig request.
        instance_type (str):
            Instance type. `Available
            types <https://cloud.google.com/bare-metal/docs/bms-planning#server_configurations>`__
        hyperthreading (bool):
            Whether the instance should be provisioned
            with Hyperthreading enabled.
        os_image (str):
            OS image to initialize the instance. `Available
            images <https://cloud.google.com/bare-metal/docs/bms-planning#server_configurations>`__
        client_network (google.cloud.bare_metal_solution_v2.types.InstanceConfig.NetworkAddress):
            Client network address. Filled if
            InstanceConfig.multivlan_config is false.
        private_network (google.cloud.bare_metal_solution_v2.types.InstanceConfig.NetworkAddress):
            Private network address, if any. Filled if
            InstanceConfig.multivlan_config is false.
        user_note (str):
            User note field, it can be used by customers
            to add additional information for the BMS Ops
            team .
        account_networks_enabled (bool):
            If true networks can be from different
            projects of the same vendor account.
        network_config (google.cloud.bare_metal_solution_v2.types.InstanceConfig.NetworkConfig):
            The type of network configuration on the
            instance.
        network_template (str):
            Server network template name. Filled if
            InstanceConfig.multivlan_config is true.
        logical_interfaces (MutableSequence[google.cloud.bare_metal_solution_v2.types.LogicalInterface]):
            List of logical interfaces for the instance. The number of
            logical interfaces will be the same as number of hardware
            bond/nic on the chosen network template. Filled if
            InstanceConfig.multivlan_config is true.
        ssh_key_names (MutableSequence[str]):
            List of names of ssh keys used to provision
            the instance.
    """

    class NetworkConfig(proto.Enum):
        r"""The network configuration of the instance.

        Values:
            NETWORKCONFIG_UNSPECIFIED (0):
                The unspecified network configuration.
            SINGLE_VLAN (1):
                Instance part of single client network and
                single private network.
            MULTI_VLAN (2):
                Instance part of multiple (or single) client
                networks and private networks.
        """
        NETWORKCONFIG_UNSPECIFIED = 0
        SINGLE_VLAN = 1
        MULTI_VLAN = 2

    class NetworkAddress(proto.Message):
        r"""A network.

        Attributes:
            network_id (str):
                Id of the network to use, within the same
                ProvisioningConfig request.
            address (str):
                IPv4 address to be assigned to the server.
            existing_network_id (str):
                Name of the existing network to use.
        """

        network_id: str = proto.Field(
            proto.STRING,
            number=1,
        )
        address: str = proto.Field(
            proto.STRING,
            number=2,
        )
        existing_network_id: str = proto.Field(
            proto.STRING,
            number=3,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    instance_type: str = proto.Field(
        proto.STRING,
        number=3,
    )
    hyperthreading: bool = proto.Field(
        proto.BOOL,
        number=4,
    )
    os_image: str = proto.Field(
        proto.STRING,
        number=5,
    )
    client_network: NetworkAddress = proto.Field(
        proto.MESSAGE,
        number=6,
        message=NetworkAddress,
    )
    private_network: NetworkAddress = proto.Field(
        proto.MESSAGE,
        number=7,
        message=NetworkAddress,
    )
    user_note: str = proto.Field(
        proto.STRING,
        number=8,
    )
    account_networks_enabled: bool = proto.Field(
        proto.BOOL,
        number=9,
    )
    network_config: NetworkConfig = proto.Field(
        proto.ENUM,
        number=10,
        enum=NetworkConfig,
    )
    network_template: str = proto.Field(
        proto.STRING,
        number=11,
    )
    logical_interfaces: MutableSequence[network.LogicalInterface] = proto.RepeatedField(
        proto.MESSAGE,
        number=12,
        message=network.LogicalInterface,
    )
    ssh_key_names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=13,
    )


class VolumeConfig(proto.Message):
    r"""Configuration parameters for a new volume.

    Attributes:
        name (str):
            Output only. The name of the volume config.
        id (str):
            A transient unique identifier to identify a
            volume within an ProvisioningConfig request.
        snapshots_enabled (bool):
            Whether snapshots should be enabled.
        type_ (google.cloud.bare_metal_solution_v2.types.VolumeConfig.Type):
            The type of this Volume.
        protocol (google.cloud.bare_metal_solution_v2.types.VolumeConfig.Protocol):
            Volume protocol.
        size_gb (int):
            The requested size of this volume, in GB.
        lun_ranges (MutableSequence[google.cloud.bare_metal_solution_v2.types.VolumeConfig.LunRange]):
            LUN ranges to be configured. Set only when protocol is
            PROTOCOL_FC.
        machine_ids (MutableSequence[str]):
            Machine ids connected to this volume. Set only when protocol
            is PROTOCOL_FC.
        nfs_exports (MutableSequence[google.cloud.bare_metal_solution_v2.types.VolumeConfig.NfsExport]):
            NFS exports. Set only when protocol is PROTOCOL_NFS.
        user_note (str):
            User note field, it can be used by customers
            to add additional information for the BMS Ops
            team .
        gcp_service (str):
            The GCP service of the storage volume. Available gcp_service
            are in
            https://cloud.google.com/bare-metal/docs/bms-planning.
        performance_tier (google.cloud.bare_metal_solution_v2.types.VolumePerformanceTier):
            Performance tier of the Volume.
            Default is SHARED.
    """

    class Type(proto.Enum):
        r"""The types of Volumes.

        Values:
            TYPE_UNSPECIFIED (0):
                The unspecified type.
            FLASH (1):
                This Volume is on flash.
            DISK (2):
                This Volume is on disk.
        """
        TYPE_UNSPECIFIED = 0
        FLASH = 1
        DISK = 2

    class Protocol(proto.Enum):
        r"""The protocol used to access the volume.

        Values:
            PROTOCOL_UNSPECIFIED (0):
                Unspecified value.
            PROTOCOL_FC (1):
                Fibre channel.
            PROTOCOL_NFS (2):
                Network file system.
        """
        PROTOCOL_UNSPECIFIED = 0
        PROTOCOL_FC = 1
        PROTOCOL_NFS = 2

    class LunRange(proto.Message):
        r"""A LUN(Logical Unit Number) range.

        Attributes:
            quantity (int):
                Number of LUNs to create.
            size_gb (int):
                The requested size of each LUN, in GB.
        """

        quantity: int = proto.Field(
            proto.INT32,
            number=1,
        )
        size_gb: int = proto.Field(
            proto.INT32,
            number=2,
        )

    class NfsExport(proto.Message):
        r"""A NFS export entry.

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            network_id (str):
                Network to use to publish the export.
            machine_id (str):
                Either a single machine, identified by an ID,
                or a comma-separated list of machine IDs.

                This field is a member of `oneof`_ ``client``.
            cidr (str):
                A CIDR range.

                This field is a member of `oneof`_ ``client``.
            permissions (google.cloud.bare_metal_solution_v2.types.VolumeConfig.NfsExport.Permissions):
                Export permissions.
            no_root_squash (bool):
                Disable root squashing, which is a feature of
                NFS. Root squash is a special mapping of the
                remote superuser (root) identity when using
                identity authentication.
            allow_suid (bool):
                Allow the setuid flag.
            allow_dev (bool):
                Allow dev flag in NfsShare
                AllowedClientsRequest.
        """

        class Permissions(proto.Enum):
            r"""Permissions that can granted for an export.

            Values:
                PERMISSIONS_UNSPECIFIED (0):
                    Unspecified value.
                READ_ONLY (1):
                    Read-only permission.
                READ_WRITE (2):
                    Read-write permission.
            """
            PERMISSIONS_UNSPECIFIED = 0
            READ_ONLY = 1
            READ_WRITE = 2

        network_id: str = proto.Field(
            proto.STRING,
            number=1,
        )
        machine_id: str = proto.Field(
            proto.STRING,
            number=2,
            oneof="client",
        )
        cidr: str = proto.Field(
            proto.STRING,
            number=3,
            oneof="client",
        )
        permissions: "VolumeConfig.NfsExport.Permissions" = proto.Field(
            proto.ENUM,
            number=4,
            enum="VolumeConfig.NfsExport.Permissions",
        )
        no_root_squash: bool = proto.Field(
            proto.BOOL,
            number=5,
        )
        allow_suid: bool = proto.Field(
            proto.BOOL,
            number=6,
        )
        allow_dev: bool = proto.Field(
            proto.BOOL,
            number=7,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    snapshots_enabled: bool = proto.Field(
        proto.BOOL,
        number=3,
    )
    type_: Type = proto.Field(
        proto.ENUM,
        number=4,
        enum=Type,
    )
    protocol: Protocol = proto.Field(
        proto.ENUM,
        number=5,
        enum=Protocol,
    )
    size_gb: int = proto.Field(
        proto.INT32,
        number=6,
    )
    lun_ranges: MutableSequence[LunRange] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message=LunRange,
    )
    machine_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=8,
    )
    nfs_exports: MutableSequence[NfsExport] = proto.RepeatedField(
        proto.MESSAGE,
        number=9,
        message=NfsExport,
    )
    user_note: str = proto.Field(
        proto.STRING,
        number=10,
    )
    gcp_service: str = proto.Field(
        proto.STRING,
        number=11,
    )
    performance_tier: common.VolumePerformanceTier = proto.Field(
        proto.ENUM,
        number=12,
        enum=common.VolumePerformanceTier,
    )


class NetworkConfig(proto.Message):
    r"""Configuration parameters for a new network.

    Attributes:
        name (str):
            Output only. The name of the network config.
        id (str):
            A transient unique identifier to identify a
            volume within an ProvisioningConfig request.
        type_ (google.cloud.bare_metal_solution_v2.types.NetworkConfig.Type):
            The type of this network, either Client or
            Private.
        bandwidth (google.cloud.bare_metal_solution_v2.types.NetworkConfig.Bandwidth):
            Interconnect bandwidth. Set only when type is
            CLIENT.
        vlan_attachments (MutableSequence[google.cloud.bare_metal_solution_v2.types.NetworkConfig.IntakeVlanAttachment]):
            List of VLAN attachments. As of now there are
            always 2 attachments, but it is going to change
            in  the future (multi vlan).
        cidr (str):
            CIDR range of the network.
        service_cidr (google.cloud.bare_metal_solution_v2.types.NetworkConfig.ServiceCidr):
            Service CIDR, if any.
        user_note (str):
            User note field, it can be used by customers
            to add additional information for the BMS Ops
            team .
        gcp_service (str):
            The GCP service of the network. Available gcp_service are in
            https://cloud.google.com/bare-metal/docs/bms-planning.
        vlan_same_project (bool):
            Whether the VLAN attachment pair is located
            in the same project.
        jumbo_frames_enabled (bool):
            The JumboFramesEnabled option for customer to
            set.
    """

    class Type(proto.Enum):
        r"""Network type.

        Values:
            TYPE_UNSPECIFIED (0):
                Unspecified value.
            CLIENT (1):
                Client network, that is a network peered to a
                GCP VPC.
            PRIVATE (2):
                Private network, that is a network local to
                the BMS POD.
        """
        TYPE_UNSPECIFIED = 0
        CLIENT = 1
        PRIVATE = 2

    class Bandwidth(proto.Enum):
        r"""Interconnect bandwidth.

        Values:
            BANDWIDTH_UNSPECIFIED (0):
                Unspecified value.
            BW_1_GBPS (1):
                1 Gbps.
            BW_2_GBPS (2):
                2 Gbps.
            BW_5_GBPS (3):
                5 Gbps.
            BW_10_GBPS (4):
                10 Gbps.
        """
        BANDWIDTH_UNSPECIFIED = 0
        BW_1_GBPS = 1
        BW_2_GBPS = 2
        BW_5_GBPS = 3
        BW_10_GBPS = 4

    class ServiceCidr(proto.Enum):
        r"""Service network block.

        Values:
            SERVICE_CIDR_UNSPECIFIED (0):
                Unspecified value.
            DISABLED (1):
                Services are disabled for the given network.
            HIGH_26 (2):
                Use the highest /26 block of the network to
                host services.
            HIGH_27 (3):
                Use the highest /27 block of the network to
                host services.
            HIGH_28 (4):
                Use the highest /28 block of the network to
                host services.
        """
        SERVICE_CIDR_UNSPECIFIED = 0
        DISABLED = 1
        HIGH_26 = 2
        HIGH_27 = 3
        HIGH_28 = 4

    class IntakeVlanAttachment(proto.Message):
        r"""A GCP vlan attachment.

        Attributes:
            id (str):
                Identifier of the VLAN attachment.
            pairing_key (str):
                Attachment pairing key.
        """

        id: str = proto.Field(
            proto.STRING,
            number=1,
        )
        pairing_key: str = proto.Field(
            proto.STRING,
            number=2,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    type_: Type = proto.Field(
        proto.ENUM,
        number=3,
        enum=Type,
    )
    bandwidth: Bandwidth = proto.Field(
        proto.ENUM,
        number=4,
        enum=Bandwidth,
    )
    vlan_attachments: MutableSequence[IntakeVlanAttachment] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=IntakeVlanAttachment,
    )
    cidr: str = proto.Field(
        proto.STRING,
        number=6,
    )
    service_cidr: ServiceCidr = proto.Field(
        proto.ENUM,
        number=7,
        enum=ServiceCidr,
    )
    user_note: str = proto.Field(
        proto.STRING,
        number=8,
    )
    gcp_service: str = proto.Field(
        proto.STRING,
        number=9,
    )
    vlan_same_project: bool = proto.Field(
        proto.BOOL,
        number=10,
    )
    jumbo_frames_enabled: bool = proto.Field(
        proto.BOOL,
        number=11,
    )


class InstanceQuota(proto.Message):
    r"""A resource budget.

    Attributes:
        name (str):
            Output only. The name of the instance quota.
        instance_type (str):
            Instance type. Deprecated: use gcp_service.
        gcp_service (str):
            The gcp service of the provisioning quota.
        location (str):
            Location where the quota applies.
        available_machine_count (int):
            Number of machines than can be created for the given
            location and instance_type.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    instance_type: str = proto.Field(
        proto.STRING,
        number=2,
    )
    gcp_service: str = proto.Field(
        proto.STRING,
        number=5,
    )
    location: str = proto.Field(
        proto.STRING,
        number=3,
    )
    available_machine_count: int = proto.Field(
        proto.INT32,
        number=4,
    )


class GetProvisioningConfigRequest(proto.Message):
    r"""Request for GetProvisioningConfig.

    Attributes:
        name (str):
            Required. Name of the ProvisioningConfig.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateProvisioningConfigRequest(proto.Message):
    r"""Request for CreateProvisioningConfig.

    Attributes:
        parent (str):
            Required. The parent project and location
            containing the ProvisioningConfig.
        provisioning_config (google.cloud.bare_metal_solution_v2.types.ProvisioningConfig):
            Required. The ProvisioningConfig to create.
        email (str):
            Optional. Email provided to send a
            confirmation with provisioning config to.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    provisioning_config: "ProvisioningConfig" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="ProvisioningConfig",
    )
    email: str = proto.Field(
        proto.STRING,
        number=3,
    )


class UpdateProvisioningConfigRequest(proto.Message):
    r"""Message for updating a ProvisioningConfig.

    Attributes:
        provisioning_config (google.cloud.bare_metal_solution_v2.types.ProvisioningConfig):
            Required. The ProvisioningConfig to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to update.
        email (str):
            Optional. Email provided to send a
            confirmation with provisioning config to.
    """

    provisioning_config: "ProvisioningConfig" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="ProvisioningConfig",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )
    email: str = proto.Field(
        proto.STRING,
        number=3,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.baremetalsolution.v2",
    manifest={
        "OSImage",
        "ListOSImagesRequest",
        "ListOSImagesResponse",
    },
)


class OSImage(proto.Message):
    r"""Operation System image.

    Attributes:
        name (str):
            Output only. OS Image's unique name.
        code (str):
            OS Image code.
        description (str):
            OS Image description.
        applicable_instance_types (MutableSequence[str]):
            Instance types this image is applicable to. `Available
            types <https://cloud.google.com/bare-metal/docs/bms-planning#server_configurations>`__
        supported_network_templates (MutableSequence[str]):
            Network templates that can be used with this
            OS Image.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    code: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    applicable_instance_types: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )
    supported_network_templates: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )


class ListOSImagesRequest(proto.Message):
    r"""Request for getting all available OS images.

    Attributes:
        parent (str):
            Required. Parent value for
            ListProvisioningQuotasRequest.
        page_size (int):
            Requested page size. The server might return fewer items
            than requested. If unspecified, server will pick an
            appropriate default. Notice that page_size field is not
            supported and won't be respected in the API request for now,
            will be updated when pagination is supported.
        page_token (str):
            A token identifying a page of results from
            the server.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListOSImagesResponse(proto.Message):
    r"""Request for getting all available OS images.

    Attributes:
        os_images (MutableSequence[google.cloud.bare_metal_solution_v2.types.OSImage]):
            The OS images available.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    os_images: MutableSequence["OSImage"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="OSImage",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
